@@ -556,6 +556,15 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
         im = images[i];
         ehu_im = casu_fits_get_ehu(im);
         ehu_cat = casu_tfits_get_ehu(cats[i]);
+
+        /*According to the PHASE 3 standard PHOTZP has to absorb the exposure
+         * time and the extinciton*/
+        phu_im = casu_fits_get_phu(im);
+        exptime = 1.0; /* Assumption in case of missing keywords */
+        extinct = 0.0; /* Assumption in case of missing keywords */
+        exptime = (float)cpl_propertylist_get_double(phu_im,expkey);
+        extinct = cpl_propertylist_get_float(ehu_im,"ESO DRS EXTINCT");
+
         cpl_propertylist_update_int(ehu_im,"ESO DRS MAGNZPTALL",nresall);
         cpl_propertylist_set_comment(ehu_im,"ESO DRS MAGNZPTALL",
                                      "number of stars in all magzpt calc");
@@ -592,7 +601,7 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
         cpl_propertylist_update_double(ehu_im,"ESO QC SKYBRIGHT",sumskbr);
         cpl_propertylist_set_comment(ehu_im,"ESO QC SKYBRIGHT",
                                      "[mag/arcsec**2] sky brightness");
-        cpl_propertylist_update_double(ehu_im,"PHOTZP",med3);
+        cpl_propertylist_update_double(ehu_im,"PHOTZP",med3 + 2.5*log10(exptime) - extinct);
         cpl_propertylist_set_comment(ehu_im,"PHOTZP",
                                      "[mag] photometric zeropoint");
         cpl_propertylist_update_double(ehu_im,"PHOTZPER",sig3det);
@@ -651,7 +660,7 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
         cpl_propertylist_update_double(ehu_cat,"ESO QC SKYBRIGHT",sumskbr);
         cpl_propertylist_set_comment(ehu_cat,"ESO QC SKYBRIGHT",
                                      "[mag/arcsec**2] sky brightness");
-        cpl_propertylist_update_double(ehu_cat,"PHOTZP",med3);
+        cpl_propertylist_update_double(ehu_cat,"PHOTZP",med3 + 2.5*log10(exptime) - extinct);
         cpl_propertylist_set_comment(ehu_cat,"PHOTZP",
                                      "[mag] photometric zeropoint");
         cpl_propertylist_update_double(ehu_cat,"PHOTZPER",sig3det);
@@ -712,7 +721,7 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
 	    cpl_propertylist_update_double(ehu_cat,"ESO QC SKYBRIGHT",sumskbr);
 	    cpl_propertylist_set_comment(ehu_cat,"ESO QC SKYBRIGHT",
 					 "[mag/arcsec**2] sky brightness");
-	    cpl_propertylist_update_double(ehu_cat,"PHOTZP",med3);
+	    cpl_propertylist_update_double(ehu_cat,"PHOTZP",med3 + 2.5*log10(exptime) - extinct);
 	    cpl_propertylist_set_comment(ehu_cat,"PHOTZP",
 					 "[mag] photometric zeropoint");
 	    cpl_propertylist_update_double(ehu_cat,"PHOTZPER",sig3det);
