@@ -1633,6 +1633,10 @@ static int hawki_sci_postproc_save_image(casu_fits *outim,
         cpl_propertylist_erase(plist,"ASSOC1");
         cpl_propertylist_erase(plist,"ASSOC2");
     } else {
+        if (cpl_propertylist_has(plist, "PHOTZP"))
+            cpl_propertylist_erase(plist,"PHOTZP");
+        if (cpl_propertylist_has(plist, "PSF_FWHM"))
+            cpl_propertylist_erase(plist,"PSF_FWHM");
         cpl_propertylist_erase(plist,"PRODCATG");
         cpl_propertylist_erase(plist,"ASSON1");
         cpl_propertylist_erase(plist,"ASSON2");
@@ -1683,6 +1687,14 @@ static int hawki_sci_postproc_save_image(casu_fits *outim,
     cpl_propertylist_set_comment(plist,"DIT","Detector integration time");
     cpl_propertylist_update_string(plist,"BUNIT","ADU");
     cpl_propertylist_set_comment(plist,"BUNIT","Physical unit of array values");
+
+    if (cpl_propertylist_has(plist,"ESO QC MAGZPT") && ndit > 0) {
+        double magzpt = cpl_propertylist_get_double(plist,"ESO QC MAGZPT");
+        cpl_propertylist_update_double(plist,"ESO QC MAGZPT TEL",
+                                       magzpt + 2.5 * log10((double)ndit));
+        cpl_propertylist_set_comment(plist,"ESO QC MAGZPT TEL",
+                                             "[mag] photometric tel zeropoint");
+    }
        
     /* Now save the data */
 
@@ -1834,6 +1846,13 @@ static int hawki_sci_postproc_save_cat(casu_tfits *outcat,
         cpl_propertylist_update_double(plist,"EXPTIME",(double)texp);
         cpl_propertylist_update_double(plist,"TEXPTIME",texp);
 
+        if (cpl_propertylist_has(plist,"ESO QC MAGZPT") && ndit > 0) {
+            double magzpt = cpl_propertylist_get_double(plist,"ESO QC MAGZPT");
+            cpl_propertylist_update_double(plist,"ESO QC MAGZPT TEL",
+                                           magzpt + 2.5 * log10((double)ndit));
+            cpl_propertylist_set_comment(plist,"ESO QC MAGZPT TEL",
+                                                 "[mag] photometric tel zeropoint");
+        }
     }
         
     /* 'Save' the PHU image */                   
@@ -1846,9 +1865,24 @@ static int hawki_sci_postproc_save_cat(casu_tfits *outcat,
     }
     cpl_frameset_insert(framelist,product_frame);
 
+
+    /* Get ndit from the primary for the correction */
+    plist = casu_tfits_get_phu(outcat);
+    hawki_pfits_get_ndit(plist,&ndit);
+
+
     /* Now save the extension */
 
     plist = casu_tfits_get_ehu(outcat);
+
+    if (cpl_propertylist_has(plist,"ESO QC MAGZPT") && ndit > 0) {
+        double magzpt = cpl_propertylist_get_double(plist,"ESO QC MAGZPT");
+        cpl_propertylist_update_double(plist,"ESO QC MAGZPT TEL",
+                                       magzpt + 2.5 * log10((double)ndit));
+        cpl_propertylist_set_comment(plist,"ESO QC MAGZPT TEL",
+                                             "[mag] photometric tel zeropoint");
+    }
+
     hawki_dfs_set_product_exten_header(plist,product_frame,framelist,
                                        parlist,HAWKI_RECIPENAME,
                                        "PRO-1.15",template);
